// Precompiled header used by the S/R Editor module
#pragma once

#define DR_PRECOMPILED_WXWIDGETS

#include "precompiled_main.h"

// Some S/R editor specifics
#include "wxutil/TreeModel.h"
#include "wxutil/dialog/MessageBox.h"

#include <fmt/format.h>
#include "string/string.h"
